About
=====

director is a python library that allows developers to create command line plugins for tools making it easy to add new functionality. 

Get it
------
You can find downloads in at `Fedora Hosted Download Site <https://fedorahosted.org/releases/d/i/director/>`_. If you want to get the latest, greatest source check out the `Development page <development.html>`_.

Development
-----------
If you'd like to get involved see the `Development page <development.html>`_.
